@@ -1,7 +1,7 @@
 from construct.lib.container import Container, FlagsContainer, ListContainer, LazyContainer, LazyRangeContainer, LazySequenceContainer, setglobalfullprinting, globalfullprinting
 from construct.lib.binary import integer2bits, integer2bytes, onebit2integer, bits2integer, bytes2integer, bytes2bits, bits2bytes, swapbytes
 from construct.lib.bitstream import RestreamedBytesIO, RebufferedBytesIO
-from construct.lib.hex import HexString, hexdump, hexundump
+from construct.lib.hex import HexString, hexdump, hexundump, hexlify, unhexlify
 from construct.lib.py3compat import PY, PY2, PY3, PY27, PY32,PY33, PY34, PY35, PY36, PY37, PYPY, supportskwordered, stringtypes, int2byte, byte2int, str2bytes, bytes2str, str2unicode, unicode2str, iteratebytes, iterateints
 
 __all__ = [
@@ -9,7 +9,7 @@ __all__ = [
     'Container', 'FlagsContainer', 'ListContainer', 'LazyContainer', 'LazyRangeContainer', 'LazySequenceContainer',
     'integer2bits', 'integer2bytes', 'onebit2integer', 'bits2integer', 'bytes2integer', 'bytes2bits', 'bits2bytes', 'swapbytes',
     'RestreamedBytesIO', 'RebufferedBytesIO',
-    'HexString', 'hexdump', 'hexundump',
+    'HexString', 'hexdump', 'hexundump', 'hexlify', 'unhexlify',
     'PY','PY2', 'PY3', 'PY27', 'PY32','PY33', 'PY34', 'PY35','PY36', 'PY37','PYPY', 'supportskwordered','stringtypes', 'int2byte', 'byte2int', 'str2bytes', 'bytes2str', 'str2unicode', 'unicode2str', 'iteratebytes', 'iterateints',
     'setglobalfullprinting','globalfullprinting',
 
