@@ -4,15 +4,14 @@ from sys import maxsize
 
 
 class RestreamedBytesIO(object):
-    __slots__ = ["substream", "encoder", "encoderunit", "decoder", "decoderunit", "decoderunitname", "rbuffer", "wbuffer","sincereadwritten"]
+    __slots__ = ["substream", "encoder", "encoderunit", "decoder", "decoderunit", "rbuffer", "wbuffer", "sincereadwritten"]
 
-    def __init__(self, substream, encoder, encoderunit, decoder, decoderunit, decoderunitname):
+    def __init__(self, substream, encoder, encoderunit, decoder, decoderunit):
         self.substream = substream
         self.encoder = encoder
         self.encoderunit = encoderunit
         self.decoder = decoder
         self.decoderunit = decoderunit
-        self.decoderunitname = decoderunitname
         self.rbuffer = b""
         self.wbuffer = b""
         self.sincereadwritten = 0
@@ -23,7 +22,7 @@ class RestreamedBytesIO(object):
         while len(self.rbuffer) < count:
             data = self.substream.read(self.decoderunit)
             if data is None or len(data) == 0:
-                raise IOError("Restreamed cannot satisfy read request of %d %s" % (count, self.decoderunitname))
+                raise IOError("Restreamed cannot satisfy read request of %d bytes" % (count,))
             self.rbuffer += self.decoder(data)
         data, self.rbuffer = self.rbuffer[:count], self.rbuffer[count:]
         self.sincereadwritten += count
@@ -40,9 +39,9 @@ class RestreamedBytesIO(object):
 
     def close(self):
         if len(self.rbuffer):
-            raise ValueError("closing stream but %d unread %s remain, %d is decoded unit" % (len(self.rbuffer), self.decoderunitname, self.decoderunit))
+            raise ValueError("closing stream but %d unread bytes remain, %d is decoded unit" % (len(self.rbuffer), self.decoderunit))
         if len(self.wbuffer):
-            raise ValueError("closing stream but %d unwritten %s remain, %d is encoded unit" % (len(self.wbuffer), self.decoderunitname, self.encoderunit))
+            raise ValueError("closing stream but %d unwritten bytes remain, %d is encoded unit" % (len(self.wbuffer), self.encoderunit))
 
     def seekable(self):
         return False
@@ -56,7 +55,7 @@ class RestreamedBytesIO(object):
 
 
 class RebufferedBytesIO(object):
-    __slots__ = ["substream","offset","rwbuffer","moved","tailcutoff"]
+    __slots__ = ["substream", "offset", "rwbuffer", "moved", "tailcutoff"]
 
     def __init__(self, substream, tailcutoff=None):
         self.substream = substream
@@ -67,7 +66,7 @@ class RebufferedBytesIO(object):
 
     def read(self, count=None):
         if count is None:
-            raise ValueError("count must be an int, reading until EOF not supported")
+            raise ValueError("count must be integer, reading until EOF not supported")
         startsat = self.offset
         endsat = startsat + count
         if startsat < self.moved:
@@ -115,7 +114,7 @@ class RebufferedBytesIO(object):
             self.offset += at
             return self.offset
         else:
-            raise ValueError("seeks only with whence 0 and 1")
+            raise ValueError("this class seeks only with whence: 0 and 1 (excluded 2)")
 
     def seekable(self):
         return True
